@@ -10,19 +10,20 @@ from typing import Optional, List, Dict, Union, Any, Type, Callable, Tuple
 from flask import Flask, Blueprint, render_template
 from pydantic import BaseModel
 
-from .api_blueprint import APIBlueprint
+from .blueprint import APIBlueprint
+from .view import APIView
 from .commands import openapi_command
 from .http import HTTPMethod
 from .models import Info, APISpec, Tag, Components, Server
 from .models.common import Reference, ExternalDocumentation, ExtraRequestBody
 from .models.oauth import OAuthConfig
 from .models.security import SecurityScheme
-from .scaffold import _Scaffold
+from .scaffold import APIScaffold
 from .utils import get_operation, get_responses, parse_and_store_tags, parse_parameters, validate_responses_type, \
     parse_method, get_operation_id_for_path
 
 
-class OpenAPI(_Scaffold, Flask):
+class OpenAPI(APIScaffold, Flask):
     def __init__(
             self,
             import_name: str,
@@ -77,11 +78,11 @@ class OpenAPI(_Scaffold, Flask):
         self.info = info
         self.security_schemes = security_schemes
         self.responses = responses or {}
-        self.paths = dict()
-        self.components_schemas = dict()
+        self.paths: Dict = dict()
+        self.components_schemas: Dict = dict()
         self.components = Components()
-        self.tags = []
-        self.tag_names = []
+        self.tags: List[Tag] = []
+        self.tag_names: List[str] = []
         self.doc_prefix = doc_prefix
         self.api_doc_url = api_doc_url
         self.swagger_url = swagger_url
@@ -92,14 +93,14 @@ class OpenAPI(_Scaffold, Flask):
                 raise TypeError("`initOAuth` must be `OAuthConfig`")
         self.oauth_config = oauth_config
         if doc_ui:
-            self.init_doc()
+            self._init_doc()
         self.doc_expansion = doc_expansion
         self.severs = servers
         self.external_docs = external_docs
         # add openapi command
         self.cli.add_command(openapi_command)
 
-    def init_doc(self) -> None:
+    def _init_doc(self) -> None:
         """
         Provide Swagger UI, Redoc and Rapidoc
         """
@@ -178,26 +179,37 @@ class OpenAPI(_Scaffold, Flask):
         for tag in api.tags:
             if tag.name not in self.tag_names:
                 self.tags.append(tag)
+                self.tag_names.append(tag.name)
         self.paths.update(**api.paths)
         self.components_schemas.update(**api.components_schemas)
         self.register_blueprint(api)
 
+    def register_api_view(self, api_view: APIView) -> None:
+        """Register APIView"""
+        for tag in api_view.tags:
+            if tag.name not in self.tag_names:
+                self.tags.append(tag)
+                self.tag_names.append(tag.name)
+        self.paths.update(**api_view.paths)
+        self.components_schemas.update(**api_view.components_schemas)
+        api_view.register(self)
+
     def _do_decorator(
             self,
             rule: str,
             func: Callable,
             *,
-            tags: List[Tag] = None,
+            tags: Optional[List[Tag]] = None,
             summary: Optional[str] = None,
             description: Optional[str] = None,
             external_docs: Optional[ExternalDocumentation] = None,
             operation_id: Optional[str] = None,
             extra_form: Optional[ExtraRequestBody] = None,
             extra_body: Optional[ExtraRequestBody] = None,
-            responses: Dict[str, Type[BaseModel]] = None,
-            extra_responses: Dict[str, dict] = None,
+            responses: Optional[Dict[str, Optional[Type[BaseModel]]]] = None,
+            extra_responses: Optional[Dict[str, Dict]] = None,
             deprecated: Optional[bool] = None,
-            security: List[Dict[str, List[Any]]] = None,
+            security: Optional[List[Dict[str, List[Any]]]] = None,
             servers: Optional[List[Server]] = None,
             doc_ui: bool = True,
             method: str = HTTPMethod.GET
@@ -243,6 +255,8 @@ class OpenAPI(_Scaffold, Flask):
             # add servers
             operation.servers = servers
             # store tags
+            if tags is None:
+                tags = []
             parse_and_store_tags(tags, self.tags, self.tag_names, operation)
             # parse parameters
             header, cookie, path, query, form, body = parse_parameters(
